/*
 * obj2hex.c
 *
 * Converts TASM generated object files to Microchip INHX8M format. 
 * By default, conversion starts assuming the origin is location 0.
 * TASM files generated for Derren Crome's EPE programmer need special 
 * treatment: the 16x84 code for a GOTO 5 instruction is stored at 
 * location 0 and the object file is dumped with an origin of 4.
 *
 *
 * Usage: obj2hex objfile hexfile [ epeflag ] 
 *
 * If the optional last argument is present (actual value ignored)
 * objfile is assumed to be an EPE programmer file.
 *
 *
 * Revision history:
 *
 * 04-Apr-1998: V-0.0; created based on JM2HEX.C
 *
 * Copyright (C) 1998 David Tait.  All rights reserved.
 * Permission is granted to use, modify, or redistribute this software
 * so long as it is not sold or exploited for profit.
 *
 * THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT WARRANTY OF ANY KIND,
 * EITHER EXPRESSED OR IMPLIED.
 *
 */


#include <stdio.h>
#include <stdlib.h>
#include "hex.h"
#include "misc.h"

static char *pname = "obj2hex";
#ifndef LIBVERSION
char *usage = "Usage: obj2hex objfile hexfile [ epeflag ]";
#endif
static char *version = "obj2hex.c V-0.0  Copyright (C) 1998 David Tait";


void obj2hex(FILE *bfp, FILE *hfp, int epeflag)
{
    int i;
    U16 *bp = progbuf;

    if ( epeflag ) {
	*bp = 0x2805;
	 bp += 4;
    }

    for ( i=4; fread(bp, 2, 1, bfp) == 1; ++i ) {
	if ( i >= PSIZE )
	    quit(pname,"illegal objfile size");
	*bp++ = SWAB(*bp);
    }

    format = INHX8M;
    dumphex(hfp, i, 0, 0, 0, 0);
}


#ifndef LIBVERSION

int main(int argc, char *argv[])
{
    int epeflag = 0;
    FILE *ifp, *ofp;

    if ( argc < 3 )
	quit(pname,usage);

    if ( argc > 3 )
	++epeflag;

    if ( (ifp = fopen(argv[1],"rb")) == NULL )
	quit(pname,"Can't open TASM objfile");

    if ( (ofp = fopen(argv[2],"w")) == NULL )
	quit(pname,"Can't create hexfile");

    erasehex(PSIZE, 0, 14);
    obj2hex(ifp, ofp, epeflag);

    return EXIT_SUCCESS;
}

#endif  /* LIBVERSION */
